.ui-widget-content { border: none !important; }
.ui-tabs .ui-tabs-nav { display: none; }
.ui-tabs .ui-tabs-hide { display: none !important; }
#grp-breadcrumbs>ul { display: inline-block !important; margin-top: 7px !important; }